@@ -10,7 +10,7 @@ FBP::Window - Base class for all graphical wxWindow objects
 
 use Mouse;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 extends 'FBP::Object';
 with    'FBP::Children';
@@ -46,19 +46,6 @@ has name => (
 
 =pod
 
-=head2 label
-
-The C<label> method returns the visual label for the object.
-
-=cut
-
-has label => (
-	is  => 'ro',
-	isa => 'Str',
-);
-
-=pod
-
 =head2 enabled
 
 The C<enabled> method indicates if the object is enabled or not.
